@@ -35,9 +35,9 @@ PowerKeysSettings::PowerKeysSettings(QWidget *parent) :
     mUi(new Ui::PowerKeysSettings)
 {
     mUi->setupUi(this);
-    fillComboBox(mUi->powerKeyActionComboBox);
-    fillComboBox(mUi->suspendKeyActionComboBox);
-    fillComboBox(mUi->hibernateKeyActionComboBox);
+    fillComboBox(mUi->powerKeyActionComboBox, true);
+    fillComboBox(mUi->suspendKeyActionComboBox, true);
+    fillComboBox(mUi->hibernateKeyActionComboBox, true);
 
     connect(mUi->powerKeyActionComboBox, QOverload<int>::of(&QComboBox::activated), this, &PowerKeysSettings::saveSettings);
     connect(mUi->suspendKeyActionComboBox, QOverload<int>::of(&QComboBox::activated), this, &PowerKeysSettings::saveSettings);
