@@ -24,16 +24,20 @@
 
 #include "idlenesswatcher.h"
 
-#include <QCoreApplication>
+#include <QGuiApplication>
 #include <QTimer>
 #include <KIdleTime>
 #include <Solid/Device>
 #include <Solid/Battery>
 #include <KWindowSystem/KWindowSystem>
+#include <KWindowSystem/KX11Extras>
 #include <KWindowSystem/KWindowInfo>
 #include <QDebug>
 #include <LXQt/lxqtnotification.h>
 #include <QObject>
+#include <QX11Info>
+#include <xcb/dpms.h>
+#include <xcb/screensaver.h>
 
 IdlenessWatcher::IdlenessWatcher(QObject* parent):
     Watcher(parent)
@@ -67,14 +71,43 @@ IdlenessWatcher::IdlenessWatcher(QObject* parent):
 
     connect(&mPSettings, &LXQt::Settings::settingsChanged, this, &IdlenessWatcher::onSettingsChanged);
 
+    // retrieve DPMS timeouts
+    mDpmsStandby = mDpmsSuspend = mDpmsOff = 0;
+    if (QGuiApplication::platformName() == QStringLiteral("xcb")) {
+        xcb_connection_t* c = QX11Info::connection();
+        xcb_dpms_get_timeouts_cookie_t cookie = xcb_dpms_get_timeouts(c);
+        xcb_dpms_get_timeouts_reply_t* reply = xcb_dpms_get_timeouts_reply(c, cookie, nullptr);
+        if (reply) {
+            mDpmsStandby = reply->standby_timeout;
+            mDpmsSuspend = reply->suspend_timeout;
+            mDpmsOff = reply->off_timeout;
+            free(reply);
+        }
+    }
+
     setup();
 }
 
 IdlenessWatcher::~IdlenessWatcher()
 {
+    setDpmsTimeouts(true);
     KIdleTime::instance()->removeAllIdleTimeouts();
 }
 
+void IdlenessWatcher::setDpmsTimeouts(bool restore) {
+    if (QGuiApplication::platformName() == QStringLiteral("xcb")) {
+        xcb_connection_t* c = QX11Info::connection();
+        if (restore) {
+            xcb_dpms_set_timeouts(c, mDpmsStandby, mDpmsSuspend, mDpmsOff);
+            xcb_screensaver_suspend(c, 0); // WARNING: This is not documented but works.
+        }
+        else {
+            xcb_dpms_set_timeouts(c, 0, 0, 0);
+            xcb_screensaver_suspend(c, XCB_SCREENSAVER_SUSPEND);
+        }
+    }
+}
+
 void IdlenessWatcher::setup()
 {
     if(mPSettings.isIdlenessWatcherEnabled()) {
@@ -108,6 +141,13 @@ void IdlenessWatcher::setup()
                 milliseconds = 1000;
             mIdleBacklightWatcher = KIdleTime::instance()->addIdleTimeout(milliseconds);
         }
+
+        // override DPMS settings
+        setDpmsTimeouts(false);
+    }
+    else {
+        // restore DPMS settings
+        setDpmsTimeouts(true);
     }
 }
 
@@ -122,7 +162,7 @@ void IdlenessWatcher::timeoutReached(int identifier,int /*msec*/)
 
     // check if disable Idleness when fullscreen is enabled
     if (mPSettings.isDisableIdlenessWhenFullscreenEnabled()) {
-        WId w = KWindowSystem::activeWindow();
+        WId w = KX11Extras::activeWindow();
         KWindowInfo info(w, NET::WMState);
         if (info.hasState(NET::FullScreen)) {
             QTimer::singleShot(0, this, [] {
