@@ -5,8 +5,8 @@
     <name>BatteryHelper</name>
     <message>
         <location filename="../batteryhelper.cpp" line="44"/>
-        <source>Empty</source>
-        <translation>فارغة</translation>
+        <source>Stable</source>
+        <translation>مستقر</translation>
     </message>
     <message>
         <location filename="../batteryhelper.cpp" line="46"/>
@@ -111,37 +111,37 @@
     </message>
     <message numerus="yes">
         <location filename="../batteryhelper.cpp" line="111"/>
-        <source>%n hour(s)</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <source>%Ln hour(s)</source>
+        <translation>
+            <numerusform>%Ln ساعة</numerusform>
+            <numerusform>%Ln ساعة</numerusform>
+            <numerusform>%Ln ساعة</numerusform>
+            <numerusform>%Ln ساعة</numerusform>
+            <numerusform>%Ln ساعة</numerusform>
+            <numerusform>%Ln ساعة</numerusform>
         </translation>
     </message>
     <message numerus="yes">
         <location filename="../batteryhelper.cpp" line="112"/>
-        <source>%n minute(s)</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <source>%Ln minute(s)</source>
+        <translation>
+            <numerusform>%Ln دقيقة</numerusform>
+            <numerusform>%Ln دقيقة</numerusform>
+            <numerusform>%Ln دقيقة</numerusform>
+            <numerusform>%Ln دقائق</numerusform>
+            <numerusform>%Ln دقيقة</numerusform>
+            <numerusform>%Ln دقيقة</numerusform>
         </translation>
     </message>
     <message>
         <location filename="../batteryhelper.cpp" line="117"/>
         <source>remaining %1</source>
-        <translation type="unfinished"></translation>
+        <translation>النسبة المتبقية %1</translation>
     </message>
     <message>
         <location filename="../batteryhelper.cpp" line="122"/>
         <source>to full %1</source>
-        <translation type="unfinished"></translation>
+        <translation>إلى %1 كاملة</translation>
     </message>
 </context>
 <context>
@@ -214,6 +214,11 @@
         <source>Vendor:</source>
         <translation>البائع:</translation>
     </message>
+    <message>
+        <location filename="../batteryinfoframe.cpp" line="65"/>
+        <source>Empty</source>
+        <translation>فارغة</translation>
+    </message>
 </context>
 <context>
     <name>BatteryWatcher</name>
@@ -234,38 +239,38 @@
     </message>
     <message numerus="yes">
         <location filename="../batterywatcher.cpp" line="131"/>
-        <source>Suspending in %n second(s)</source>
-        <translation type="unfinished">
-            <numerusform>سيُعلّق الحاسوب بعد %n ثوان</numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <source>Suspending in %Ln second(s)</source>
+        <translation>
+            <numerusform>تعليق في %Ln ثانية</numerusform>
+            <numerusform>تعليق في %Ln ثانية</numerusform>
+            <numerusform>تعليق في %Ln ثانية</numerusform>
+            <numerusform>تعليق في %Ln ثانية</numerusform>
+            <numerusform>تعليق في %Ln ثانية</numerusform>
+            <numerusform>تعليق في %Ln ثانية</numerusform>
         </translation>
     </message>
     <message numerus="yes">
         <location filename="../batterywatcher.cpp" line="134"/>
-        <source>Hibernating in %n second(s)</source>
-        <translation type="unfinished">
-            <numerusform>سيُسبت الحاسوب بعد %n ثوان</numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <source>Hibernating in %Ln second(s)</source>
+        <translation>
+            <numerusform>تسبت في %Ln ثانية</numerusform>
+            <numerusform>تسبت في %Ln ثانية</numerusform>
+            <numerusform>تسبت في %Ln ثانية</numerusform>
+            <numerusform>تسبت في %Ln ثانية</numerusform>
+            <numerusform>تسبت في %Ln ثانية</numerusform>
+            <numerusform>تسبت في %Ln ثانية</numerusform>
         </translation>
     </message>
     <message numerus="yes">
         <location filename="../batterywatcher.cpp" line="137"/>
-        <source>Shutting down in %n second(s)</source>
-        <translation type="unfinished">
-            <numerusform>سيُطفأ الحاسوب بعد %n ثوان</numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <source>Shutting down in %Ln second(s)</source>
+        <translation>
+            <numerusform>اغلاق في %Ln ثانية</numerusform>
+            <numerusform>اغلاق في %Ln ثانية</numerusform>
+            <numerusform>اغلاق في %Ln ثانية</numerusform>
+            <numerusform>اغلاق في %Ln ثانية</numerusform>
+            <numerusform>اغلاق في %Ln ثانية</numerusform>
+            <numerusform>اغلاق في %Ln ثانية</numerusform>
         </translation>
     </message>
 </context>
@@ -274,17 +279,17 @@
     <message>
         <location filename="../powerbutton.cpp" line="72"/>
         <source>Power off key action</source>
-        <translation type="unfinished"></translation>
+        <translation>إيقاف تشغيل الإجراء الرئيسي</translation>
     </message>
     <message>
         <location filename="../powerbutton.cpp" line="79"/>
         <source>Suspend key action</source>
-        <translation type="unfinished"></translation>
+        <translation>تعليق الإجراء الرئيسي</translation>
     </message>
     <message>
         <location filename="../powerbutton.cpp" line="86"/>
         <source>Hibernate key action</source>
-        <translation type="unfinished"></translation>
+        <translation>الإجراء الرئيسي للسبات</translation>
     </message>
 </context>
 <context>
@@ -317,36 +322,36 @@ You can configure it from settings... </source>
     <message>
         <location filename="../trayicon.cpp" line="75"/>
         <source>30 minutes</source>
-        <translation type="unfinished"></translation>
+        <translation>30 دقیقة</translation>
     </message>
     <message>
         <location filename="../trayicon.cpp" line="79"/>
         <source>1 hour</source>
-        <translation type="unfinished"></translation>
+        <translation>1 ساعة</translation>
     </message>
     <message>
         <location filename="../trayicon.cpp" line="83"/>
         <source>2 hours</source>
-        <translation type="unfinished"></translation>
+        <translation>2 ساعة</translation>
     </message>
     <message>
         <location filename="../trayicon.cpp" line="87"/>
         <source>3 hours</source>
-        <translation type="unfinished"></translation>
+        <translation>3 ساعات</translation>
     </message>
     <message>
         <location filename="../trayicon.cpp" line="91"/>
         <source>4 hours</source>
-        <translation type="unfinished"></translation>
+        <translation>4 ساعات</translation>
     </message>
     <message>
         <location filename="../trayicon.cpp" line="96"/>
         <source>Pause idleness checks</source>
-        <translation type="unfinished"></translation>
+        <translation>إيقاف فحوصات الخمول مؤقتا</translation>
     </message>
     <message>
         <location filename="../trayicon.cpp" line="101"/>
-        <location filename="../trayicon.cpp" line="191"/>
+        <location filename="../trayicon.cpp" line="193"/>
         <source>About</source>
         <translation>عن</translation>
     </message>
@@ -356,22 +361,27 @@ You can configure it from settings... </source>
         <translation>عطّل الأيقونة</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="192"/>
+        <location filename="../trayicon.cpp" line="162"/>
+        <source>Empty</source>
+        <translation>فارغ</translation>
+    </message>
+    <message>
+        <location filename="../trayicon.cpp" line="194"/>
         <source>&lt;p&gt;  &lt;b&gt;LXQt Power Management&lt;/b&gt;&lt;br/&gt;  - Power Management for the LXQt Desktop Environment&lt;/p&gt;&lt;p&gt;  Authors:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - and others from the Razor and LXQt projects&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</source>
         <translation>&lt;p&gt;  &lt;b&gt;إدارة لكسكيوت للطاقة&lt;/b&gt;&lt;br/&gt;  - إدارة طاقة لبيئة سطح مكتب لكسكيوت&lt;/p&gt;&lt;p&gt;  المؤلفون:&lt;br/&gt;  &amp;nbsp; Christian Surlykke و Alec Moskvin&lt;br/&gt;  &amp;nbsp; - وآخرين من مشروعي ريزر ولكسكيوت&lt;/p&gt;&lt;p&gt;  الحقوق محفوظة &amp;copy; ٢٠١٢-٢٠١٤&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="210"/>
+        <location filename="../trayicon.cpp" line="212"/>
         <source>LXQt Power Management info</source>
         <translation>معلومات لكسكيوت لإدارة الطاقة</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="211"/>
+        <location filename="../trayicon.cpp" line="213"/>
         <source>The LXQt Power Management tray icon can be (re)enabled in &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</source>
         <translation>يمكن تفعيل/إعادة تفعيل أيقونة صينية النظام لإدارة لكسكيوت للطاقة من &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="213"/>
+        <location filename="../trayicon.cpp" line="215"/>
         <source>Configure now</source>
         <translation>اضبط الآن</translation>
     </message>
