@@ -6,7 +6,7 @@
     <message>
         <location filename="../batteryhelper.cpp" line="44"/>
         <source>Stable</source>
-        <translation type="unfinished"></translation>
+        <translation>Stabilní</translation>
     </message>
     <message>
         <location filename="../batteryhelper.cpp" line="46"/>
@@ -111,19 +111,19 @@
     <message numerus="yes">
         <location filename="../batteryhelper.cpp" line="111"/>
         <source>%Ln hour(s)</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>%Ln hodina</numerusform>
+            <numerusform>%Ln hodiny</numerusform>
+            <numerusform>%Ln hodin</numerusform>
         </translation>
     </message>
     <message numerus="yes">
         <location filename="../batteryhelper.cpp" line="112"/>
         <source>%Ln minute(s)</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>%Ln minuta</numerusform>
+            <numerusform>%Ln minuty</numerusform>
+            <numerusform>%Ln minut</numerusform>
         </translation>
     </message>
     <message>
@@ -210,7 +210,7 @@
     <message>
         <location filename="../batteryinfoframe.cpp" line="65"/>
         <source>Empty</source>
-        <translation type="unfinished">Téměř vybito</translation>
+        <translation>Téměř vybito</translation>
     </message>
 </context>
 <context>
@@ -233,28 +233,28 @@
     <message numerus="yes">
         <location filename="../batterywatcher.cpp" line="131"/>
         <source>Suspending in %Ln second(s)</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>Uspání za %Ln sekundu</numerusform>
+            <numerusform>Uspání za %Ln sekundy</numerusform>
+            <numerusform>Uspání za %Ln sekund</numerusform>
         </translation>
     </message>
     <message numerus="yes">
         <location filename="../batterywatcher.cpp" line="134"/>
         <source>Hibernating in %Ln second(s)</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>Hibernace za %Ln sekundu</numerusform>
+            <numerusform>Hibernace za %Ln sekundy</numerusform>
+            <numerusform>Hibernace za %Ln sekund</numerusform>
         </translation>
     </message>
     <message numerus="yes">
         <location filename="../batterywatcher.cpp" line="137"/>
         <source>Shutting down in %Ln second(s)</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>Vypnutí za %Ln sekundu</numerusform>
+            <numerusform>Vypnutí za %Ln sekundy</numerusform>
+            <numerusform>Vypnutí za %Ln sekund</numerusform>
         </translation>
     </message>
 </context>
@@ -347,7 +347,7 @@ Parametry je možné upravit v nastavení… </translation>
     <message>
         <location filename="../trayicon.cpp" line="162"/>
         <source>Empty</source>
-        <translation type="unfinished">Téměř vybito</translation>
+        <translation>Téměř vybito</translation>
     </message>
     <message>
         <location filename="../trayicon.cpp" line="194"/>
