@@ -6,7 +6,7 @@
     <message>
         <location filename="../batteryhelper.cpp" line="44"/>
         <source>Stable</source>
-        <translation type="unfinished"></translation>
+        <translation>Σταθερή</translation>
     </message>
     <message>
         <location filename="../batteryhelper.cpp" line="46"/>
@@ -111,17 +111,17 @@
     <message numerus="yes">
         <location filename="../batteryhelper.cpp" line="111"/>
         <source>%Ln hour(s)</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>%Ln ώρα</numerusform>
+            <numerusform>%Ln ώρες</numerusform>
         </translation>
     </message>
     <message numerus="yes">
         <location filename="../batteryhelper.cpp" line="112"/>
         <source>%Ln minute(s)</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>%Ln λεπτό</numerusform>
+            <numerusform>%Ln λεπτά</numerusform>
         </translation>
     </message>
     <message>
@@ -208,7 +208,7 @@
     <message>
         <location filename="../batteryinfoframe.cpp" line="65"/>
         <source>Empty</source>
-        <translation type="unfinished">Αποφορτισμένος</translation>
+        <translation>Αποφορτισμένος</translation>
     </message>
 </context>
 <context>
@@ -231,25 +231,25 @@
     <message numerus="yes">
         <location filename="../batterywatcher.cpp" line="131"/>
         <source>Suspending in %Ln second(s)</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>Αναστολή σε %Ln δευτερόλεπτο</numerusform>
+            <numerusform>Αναστολή σε %Ln δευτερόλεπτα</numerusform>
         </translation>
     </message>
     <message numerus="yes">
         <location filename="../batterywatcher.cpp" line="134"/>
         <source>Hibernating in %Ln second(s)</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>Νάρκωση σε %Ln δευτερόλεπτο</numerusform>
+            <numerusform>Νάρκωση σε %Ln δευτερόλεπτα</numerusform>
         </translation>
     </message>
     <message numerus="yes">
         <location filename="../batterywatcher.cpp" line="137"/>
         <source>Shutting down in %Ln second(s)</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>Τερματισμός σε %Ln δευτερόλεπτο</numerusform>
+            <numerusform>Τερματισμός σε %Ln δευτερόλεπτα</numerusform>
         </translation>
     </message>
 </context>
@@ -343,7 +343,7 @@ You can configure it from settings... </source>
     <message>
         <location filename="../trayicon.cpp" line="162"/>
         <source>Empty</source>
-        <translation type="unfinished">Αποφορτισμένος</translation>
+        <translation>Αποφορτισμένος</translation>
     </message>
     <message>
         <location filename="../trayicon.cpp" line="194"/>
