@@ -6,7 +6,7 @@
     <message>
         <location filename="../batteryhelper.cpp" line="44"/>
         <source>Stable</source>
-        <translation type="unfinished"></translation>
+        <translation>Stabilne</translation>
     </message>
     <message>
         <location filename="../batteryhelper.cpp" line="46"/>
@@ -111,19 +111,19 @@
     <message numerus="yes">
         <location filename="../batteryhelper.cpp" line="111"/>
         <source>%Ln hour(s)</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>%Ln godzina</numerusform>
+            <numerusform>%Ln godziny</numerusform>
+            <numerusform>%Ln godzin</numerusform>
         </translation>
     </message>
     <message numerus="yes">
         <location filename="../batteryhelper.cpp" line="112"/>
         <source>%Ln minute(s)</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>%Ln minuta</numerusform>
+            <numerusform>%Ln minuty</numerusform>
+            <numerusform>%Ln minut</numerusform>
         </translation>
     </message>
     <message>
@@ -210,7 +210,7 @@
     <message>
         <location filename="../batteryinfoframe.cpp" line="65"/>
         <source>Empty</source>
-        <translation type="unfinished">Pusta</translation>
+        <translation>Pusta</translation>
     </message>
 </context>
 <context>
@@ -233,28 +233,28 @@
     <message numerus="yes">
         <location filename="../batterywatcher.cpp" line="131"/>
         <source>Suspending in %Ln second(s)</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>Zawieszenie za %Ln sekundę</numerusform>
+            <numerusform>Zawieszenie za %Ln sekundy</numerusform>
+            <numerusform>Zawieszenie za %Ln sekund</numerusform>
         </translation>
     </message>
     <message numerus="yes">
         <location filename="../batterywatcher.cpp" line="134"/>
         <source>Hibernating in %Ln second(s)</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>Hibernacja za %Ln sekundę</numerusform>
+            <numerusform>Hibernacja za %Ln sekundy</numerusform>
+            <numerusform>Hibernacja za %Ln sekund</numerusform>
         </translation>
     </message>
     <message numerus="yes">
         <location filename="../batterywatcher.cpp" line="137"/>
         <source>Shutting down in %Ln second(s)</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>Wyłączenie za %Ln sekundę</numerusform>
+            <numerusform>Wyłączenie za %Ln sekundy</numerusform>
+            <numerusform>Wyłączenie za %Ln sekund</numerusform>
         </translation>
     </message>
 </context>
@@ -347,7 +347,7 @@ Możesz skonfigurować jego ustawienia… </translation>
     <message>
         <location filename="../trayicon.cpp" line="162"/>
         <source>Empty</source>
-        <translation type="unfinished">Pusta</translation>
+        <translation>Pusta</translation>
     </message>
     <message>
         <location filename="../trayicon.cpp" line="194"/>
