@@ -6,7 +6,7 @@
     <message>
         <location filename="../batteryhelper.cpp" line="44"/>
         <source>Stable</source>
-        <translation type="unfinished"></translation>
+        <translation>Стабильный</translation>
     </message>
     <message>
         <location filename="../batteryhelper.cpp" line="46"/>
@@ -111,19 +111,19 @@
     <message numerus="yes">
         <location filename="../batteryhelper.cpp" line="111"/>
         <source>%Ln hour(s)</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>%Ln час</numerusform>
+            <numerusform>%Ln часа</numerusform>
+            <numerusform>%Ln часов</numerusform>
         </translation>
     </message>
     <message numerus="yes">
         <location filename="../batteryhelper.cpp" line="112"/>
         <source>%Ln minute(s)</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>%Ln минута</numerusform>
+            <numerusform>%Ln минуты</numerusform>
+            <numerusform>%Ln минут</numerusform>
         </translation>
     </message>
     <message>
@@ -210,7 +210,7 @@
     <message>
         <location filename="../batteryinfoframe.cpp" line="65"/>
         <source>Empty</source>
-        <translation type="unfinished">Пустая</translation>
+        <translation>Разряжена</translation>
     </message>
 </context>
 <context>
@@ -233,28 +233,28 @@
     <message numerus="yes">
         <location filename="../batterywatcher.cpp" line="131"/>
         <source>Suspending in %Ln second(s)</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>Ждущий режим через %Ln секунду</numerusform>
+            <numerusform>Ждущий режим через %Ln секунды</numerusform>
+            <numerusform>Ждущий режим через %Ln секунд</numerusform>
         </translation>
     </message>
     <message numerus="yes">
         <location filename="../batterywatcher.cpp" line="134"/>
         <source>Hibernating in %Ln second(s)</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>Спящий режим через %Ln секунду</numerusform>
+            <numerusform>Спящий режим через %Ln секунды</numerusform>
+            <numerusform>Спящий режим через %Ln секунд</numerusform>
         </translation>
     </message>
     <message numerus="yes">
         <location filename="../batterywatcher.cpp" line="137"/>
         <source>Shutting down in %Ln second(s)</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-            <numerusform></numerusform>
+        <translation>
+            <numerusform>Выключение через %Ln секунду</numerusform>
+            <numerusform>Выключение через %Ln секунды</numerusform>
+            <numerusform>Выключение через %Ln секунд</numerusform>
         </translation>
     </message>
 </context>
@@ -347,7 +347,7 @@ You can configure it from settings... </source>
     <message>
         <location filename="../trayicon.cpp" line="162"/>
         <source>Empty</source>
-        <translation type="unfinished">Пустая</translation>
+        <translation>Разряжена</translation>
     </message>
     <message>
         <location filename="../trayicon.cpp" line="194"/>
